<?php
session_start(); // Initialize Session data
ob_start(); // Turn on output buffering
?>
<?php include "ewcfg7.php" ?>
<?php include "ewmysql7.php" ?>
<?php include "phpfn7.php" ?>
<?php include "tbl_countryinfo.php" ?>
<?php include "tbl_languageinfo.php" ?>
<?php include "tbl_country_originalinfo.php" ?>
<?php include "tbl_admininfo.php" ?>
<?php include "userfn7.php" ?>
<?php
header("Expires: Mon, 26 Jul 1997 05:00:00 GMT"); // Date in the past
header("Last-Modified: " . gmdate("D, d M Y H:i:s") . " GMT"); // Always modified
header("Cache-Control: private, no-store, no-cache, must-revalidate"); // HTTP/1.1 
header("Cache-Control: post-check=0, pre-check=0", false);
header("Pragma: no-cache"); // HTTP/1.0
?>
<?php

// Create page object
$tbl_country_delete = new ctbl_country_delete();
$Page =& $tbl_country_delete;

// Page init
$tbl_country_delete->Page_Init();

// Page main
$tbl_country_delete->Page_Main();
?>
<?php include "header.php" ?>
<script type="text/javascript">
<!--

// Create page object
var tbl_country_delete = new ew_Page("tbl_country_delete");

// page properties
tbl_country_delete.PageID = "delete"; // page ID
tbl_country_delete.FormID = "ftbl_countrydelete"; // form ID
var EW_PAGE_ID = tbl_country_delete.PageID; // for backward compatibility

// extend page with Form_CustomValidate function
tbl_country_delete.Form_CustomValidate =  
 function(fobj) { // DO NOT CHANGE THIS LINE!

 	// Your custom validation code here, return false if invalid. 
 	return true;
 }
<?php if (EW_CLIENT_VALIDATE) { ?>
tbl_country_delete.ValidateRequired = true; // uses JavaScript validation
<?php } else { ?>
tbl_country_delete.ValidateRequired = false; // no JavaScript validation
<?php } ?>

//-->
</script>
<script language="JavaScript" type="text/javascript">
<!--

// Write your client script here, no need to add script tags.
// To include another .js script, use:
// ew_ClientScriptInclude("my_javascript.js"); 
//-->

</script>
<?php

// Load records for display
if ($rs = $tbl_country_delete->LoadRecordset())
	$tbl_country_deletelTotalRecs = $rs->RecordCount(); // Get record count
if ($tbl_country_deletelTotalRecs <= 0) { // No record found, exit
	if ($rs)
		$rs->Close();
	$tbl_country_delete->Page_Terminate("tbl_countrylist.php"); // Return to list
}
?>
<p><span class="phpmaker"><?php echo $Language->Phrase("Delete") ?>&nbsp;<?php echo $Language->Phrase("TblTypeTABLE") ?><?php echo $tbl_country->TableCaption() ?><br><br>
<a href="<?php echo $tbl_country->getReturnUrl() ?>"><?php echo $Language->Phrase("GoBack") ?></a></span></p>
<?php
if (EW_DEBUG_ENABLED)
	echo ew_DebugMsg();
$tbl_country_delete->ShowMessage();
?>
<form action="<?php echo ew_CurrentPage() ?>" method="post">
<p>
<input type="hidden" name="t" id="t" value="tbl_country">
<input type="hidden" name="a_delete" id="a_delete" value="D">
<?php foreach ($tbl_country_delete->arRecKeys as $key) { ?>
<input type="hidden" name="key_m[]" id="key_m[]" value="<?php echo ew_HtmlEncode($key) ?>">
<?php } ?>
<table class="ewGrid"><tr><td class="ewGridContent">
<div class="ewGridMiddlePanel">
<table cellspacing="0" class="ewTable ewTableSeparate">
<?php echo $tbl_country->TableCustomInnerHtml ?>
	<thead>
	<tr class="ewTableHeader">
		<td valign="top"><?php echo $tbl_country->lagnuage_id->FldCaption() ?></td>
		<td valign="top"><?php echo $tbl_country->country_name->FldCaption() ?></td>
		<td valign="top"><?php echo $tbl_country->order_by->FldCaption() ?></td>
	</tr>
	</thead>
	<tbody>
<?php
$tbl_country_delete->lRecCnt = 0;
$i = 0;
while (!$rs->EOF) {
	$tbl_country_delete->lRecCnt++;

	// Set row properties
	$tbl_country->CssClass = "";
	$tbl_country->CssStyle = "";
	$tbl_country->RowAttrs = array();
	$tbl_country->RowType = EW_ROWTYPE_VIEW; // View

	// Get the field contents
	$tbl_country_delete->LoadRowValues($rs);

	// Render row
	$tbl_country_delete->RenderRow();
?>
	<tr<?php echo $tbl_country->RowAttributes() ?>>
		<td<?php echo $tbl_country->lagnuage_id->CellAttributes() ?>>
<div<?php echo $tbl_country->lagnuage_id->ViewAttributes() ?>><?php echo $tbl_country->lagnuage_id->ListViewValue() ?></div></td>
		<td<?php echo $tbl_country->country_name->CellAttributes() ?>>
<div<?php echo $tbl_country->country_name->ViewAttributes() ?>><?php echo $tbl_country->country_name->ListViewValue() ?></div></td>
		<td<?php echo $tbl_country->order_by->CellAttributes() ?>>
<div<?php echo $tbl_country->order_by->ViewAttributes() ?>><?php echo $tbl_country->order_by->ListViewValue() ?></div></td>
	</tr>
<?php
	$rs->MoveNext();
}
$rs->Close();
?>
</tbody>
</table>
</div>
</td></tr></table>
<p>
<input type="submit" name="Action" id="Action" value="<?php echo ew_BtnCaption($Language->Phrase("DeleteBtn")) ?>">
</form>
<script language="JavaScript" type="text/javascript">
<!--

// Write your table-specific startup script here
// document.write("page loaded");
//-->

</script>
<?php include "footer.php" ?>
<?php
$tbl_country_delete->Page_Terminate();
?>
<?php

//
// Page class
//
class ctbl_country_delete {

	// Page ID
	var $PageID = 'delete';

	// Table name
	var $TableName = 'tbl_country';

	// Page object name
	var $PageObjName = 'tbl_country_delete';

	// Page name
	function PageName() {
		return ew_CurrentPage();
	}

	// Page URL
	function PageUrl() {
		$PageUrl = ew_CurrentPage() . "?";
		global $tbl_country;
		if ($tbl_country->UseTokenInUrl) $PageUrl .= "t=" . $tbl_country->TableVar . "&"; // Add page token
		return $PageUrl;
	}

	// Page URLs
	var $AddUrl;
	var $EditUrl;
	var $CopyUrl;
	var $DeleteUrl;
	var $ViewUrl;
	var $ListUrl;

	// Export URLs
	var $ExportPrintUrl;
	var $ExportHtmlUrl;
	var $ExportExcelUrl;
	var $ExportWordUrl;
	var $ExportXmlUrl;
	var $ExportCsvUrl;

	// Update URLs
	var $InlineAddUrl;
	var $InlineCopyUrl;
	var $InlineEditUrl;
	var $GridAddUrl;
	var $GridEditUrl;
	var $MultiDeleteUrl;
	var $MultiUpdateUrl;

	// Message
	function getMessage() {
		return @$_SESSION[EW_SESSION_MESSAGE];
	}

	function setMessage($v) {
		if (@$_SESSION[EW_SESSION_MESSAGE] <> "") { // Append
			$_SESSION[EW_SESSION_MESSAGE] .= "<br>" . $v;
		} else {
			$_SESSION[EW_SESSION_MESSAGE] = $v;
		}
	}

	// Show message
	function ShowMessage() {
		$sMessage = $this->getMessage();
		$this->Message_Showing($sMessage);
		if ($sMessage <> "") { // Message in Session, display
			echo "<p><span class=\"ewMessage\">" . $sMessage . "</span></p>";
			$_SESSION[EW_SESSION_MESSAGE] = ""; // Clear message in Session
		}
	}

	// Validate page request
	function IsPageRequest() {
		global $objForm, $tbl_country;
		if ($tbl_country->UseTokenInUrl) {
			if ($objForm)
				return ($tbl_country->TableVar == $objForm->GetValue("t"));
			if (@$_GET["t"] <> "")
				return ($tbl_country->TableVar == $_GET["t"]);
		} else {
			return TRUE;
		}
	}

	//
	// Page class constructor
	//
	function ctbl_country_delete() {
		global $conn, $Language;

		// Language object
		$Language = new cLanguage();

		// Table object (tbl_country)
		$GLOBALS["tbl_country"] = new ctbl_country();

		// Table object (tbl_language)
		$GLOBALS['tbl_language'] = new ctbl_language();

		// Table object (tbl_country_original)
		$GLOBALS['tbl_country_original'] = new ctbl_country_original();

		// Table object (tbl_admin)
		$GLOBALS['tbl_admin'] = new ctbl_admin();

		// Page ID
		if (!defined("EW_PAGE_ID"))
			define("EW_PAGE_ID", 'delete', TRUE);

		// Table name (for backward compatibility)
		if (!defined("EW_TABLE_NAME"))
			define("EW_TABLE_NAME", 'tbl_country', TRUE);

		// Start timer
		$GLOBALS["gsTimer"] = new cTimer();

		// Open connection
		$conn = ew_Connect();
	}

	// 
	//  Page_Init
	//
	function Page_Init() {
		global $gsExport, $gsExportFile, $UserProfile, $Language, $Security, $objForm;
		global $tbl_country;

		// Security
		$Security = new cAdvancedSecurity();
		if (!$Security->IsLoggedIn()) $Security->AutoLogin();
		if (!$Security->IsLoggedIn()) {
			$Security->SaveLastUrl();
			$this->Page_Terminate("login.php");
		}

		// Global Page Loading event (in userfn*.php)
		Page_Loading();

		// Page Load event
		$this->Page_Load();
	}

	//
	// Page_Terminate
	//
	function Page_Terminate($url = "") {
		global $conn;

		// Page Unload event
		$this->Page_Unload();

		// Global Page Unloaded event (in userfn*.php)
		Page_Unloaded();

		 // Close connection
		$conn->Close();

		// Go to URL if specified
		$this->Page_Redirecting($url);
		if ($url <> "") {
			if (!EW_DEBUG_ENABLED && ob_get_length())
				ob_end_clean();
			header("Location: " . $url);
		}
		exit();
	}
	var $lTotalRecs = 0;
	var $lRecCnt;
	var $arRecKeys = array();

	//
	// Page main
	//
	function Page_Main() {
		global $Language, $tbl_country;

		// Load key parameters
		$sKey = "";
		$bSingleDelete = TRUE; // Initialize as single delete
		$nKeySelected = 0; // Initialize selected key count
		$sFilter = "";
		if (@$_GET["country_id"] <> "") {
			$tbl_country->country_id->setQueryStringValue($_GET["country_id"]);
			if (!is_numeric($tbl_country->country_id->QueryStringValue))
				$this->Page_Terminate("tbl_countrylist.php"); // Prevent SQL injection, exit
			$sKey .= $tbl_country->country_id->QueryStringValue;
		} else {
			$bSingleDelete = FALSE;
		}
		if ($bSingleDelete) {
			$nKeySelected = 1; // Set up key selected count
			$this->arRecKeys[0] = $sKey;
		} else {
			if (isset($_POST["key_m"])) { // Key in form
				$nKeySelected = count($_POST["key_m"]); // Set up key selected count
				$this->arRecKeys = ew_StripSlashes($_POST["key_m"]);
			}
		}
		if ($nKeySelected <= 0)
			$this->Page_Terminate("tbl_countrylist.php"); // No key specified, return to list

		// Build filter
		foreach ($this->arRecKeys as $sKey) {
			$sFilter .= "(";

			// Set up key field
			$sKeyFld = $sKey;
			if (!is_numeric($sKeyFld))
				$this->Page_Terminate("tbl_countrylist.php"); // Prevent SQL injection, return to list
			$sFilter .= "`country_id`=" . ew_AdjustSql($sKeyFld) . " AND ";
			if (substr($sFilter, -5) == " AND ") $sFilter = substr($sFilter, 0, strlen($sFilter)-5) . ") OR ";
		}
		if (substr($sFilter, -4) == " OR ") $sFilter = substr($sFilter, 0, strlen($sFilter)-4);

		// Set up filter (SQL WHHERE clause) and get return SQL
		// SQL constructor in tbl_country class, tbl_countryinfo.php

		$tbl_country->CurrentFilter = $sFilter;

		// Get action
		if (@$_POST["a_delete"] <> "") {
			$tbl_country->CurrentAction = $_POST["a_delete"];
		} else {
			$tbl_country->CurrentAction = "D"; // Delete record directly
		}
		switch ($tbl_country->CurrentAction) {
			case "D": // Delete
				$tbl_country->SendEmail = TRUE; // Send email on delete success
				if ($this->DeleteRows()) { // delete rows
					$this->setMessage($Language->Phrase("DeleteSuccess")); // Set up success message
					$this->Page_Terminate($tbl_country->getReturnUrl()); // Return to caller
				}
		}
	}

	//
	// Delete records based on current filter
	//
	function DeleteRows() {
		global $conn, $Language, $Security, $tbl_country;
		$DeleteRows = TRUE;
		$sWrkFilter = $tbl_country->CurrentFilter;

		// Set up filter (SQL WHERE clause) and get return SQL
		// SQL constructor in tbl_country class, tbl_countryinfo.php

		$tbl_country->CurrentFilter = $sWrkFilter;
		$sSql = $tbl_country->SQL();
		$conn->raiseErrorFn = 'ew_ErrorFn';
		$rs = $conn->Execute($sSql);
		$conn->raiseErrorFn = '';
		if ($rs === FALSE) {
			return FALSE;
		} elseif ($rs->EOF) {
			$this->setMessage($Language->Phrase("NoRecord")); // No record found
			$rs->Close();
			return FALSE;
		}
		$conn->BeginTrans();

		// Clone old rows
		$rsold = ($rs) ? $rs->GetRows() : array();
		if ($rs)
			$rs->Close();

		// Call row deleting event
		if ($DeleteRows) {
			foreach ($rsold as $row) {
				$DeleteRows = $tbl_country->Row_Deleting($row);
				if (!$DeleteRows) break;
			}
		}
		if ($DeleteRows) {
			$sKey = "";
			foreach ($rsold as $row) {
				$sThisKey = "";
				if ($sThisKey <> "") $sThisKey .= EW_COMPOSITE_KEY_SEPARATOR;
				$sThisKey .= $row['country_id'];
				$conn->raiseErrorFn = 'ew_ErrorFn';
				$DeleteRows = $conn->Execute($tbl_country->DeleteSQL($row)); // Delete
				$conn->raiseErrorFn = '';
				if ($DeleteRows === FALSE)
					break;
				if ($sKey <> "") $sKey .= ", ";
				$sKey .= $sThisKey;
			}
		} else {

			// Set up error message
			if ($tbl_country->CancelMessage <> "") {
				$this->setMessage($tbl_country->CancelMessage);
				$tbl_country->CancelMessage = "";
			} else {
				$this->setMessage($Language->Phrase("DeleteCancelled"));
			}
		}
		if ($DeleteRows) {
			$conn->CommitTrans(); // Commit the changes
		} else {
			$conn->RollbackTrans(); // Rollback changes
		}

		// Call Row Deleted event
		if ($DeleteRows) {
			foreach ($rsold as $row) {
				$tbl_country->Row_Deleted($row);
			}	
		}
		return $DeleteRows;
	}

	// Load recordset
	function LoadRecordset($offset = -1, $rowcnt = -1) {
		global $conn, $tbl_country;

		// Call Recordset Selecting event
		$tbl_country->Recordset_Selecting($tbl_country->CurrentFilter);

		// Load List page SQL
		$sSql = $tbl_country->SelectSQL();
		if ($offset > -1 && $rowcnt > -1)
			$sSql .= " LIMIT $offset, $rowcnt";

		// Load recordset
		$rs = ew_LoadRecordset($sSql);

		// Call Recordset Selected event
		$tbl_country->Recordset_Selected($rs);
		return $rs;
	}

	// Load row based on key values
	function LoadRow() {
		global $conn, $Security, $tbl_country;
		$sFilter = $tbl_country->KeyFilter();

		// Call Row Selecting event
		$tbl_country->Row_Selecting($sFilter);

		// Load SQL based on filter
		$tbl_country->CurrentFilter = $sFilter;
		$sSql = $tbl_country->SQL();
		$res = FALSE;
		$rs = ew_LoadRecordset($sSql);
		if ($rs && !$rs->EOF) {
			$res = TRUE;
			$this->LoadRowValues($rs); // Load row values

			// Call Row Selected event
			$tbl_country->Row_Selected($rs);
			$rs->Close();
		}
		return $res;
	}

	// Load row values from recordset
	function LoadRowValues(&$rs) {
		global $conn, $tbl_country;
		$tbl_country->country_id->setDbValue($rs->fields('country_id'));
		$tbl_country->country_or_id->setDbValue($rs->fields('country_or_id'));
		$tbl_country->lagnuage_id->setDbValue($rs->fields('lagnuage_id'));
		$tbl_country->country_name->setDbValue($rs->fields('country_name'));
		$tbl_country->order_by->setDbValue($rs->fields('order_by'));
	}

	// Render row values based on field settings
	function RenderRow() {
		global $conn, $Security, $Language, $tbl_country;

		// Initialize URLs
		// Call Row_Rendering event

		$tbl_country->Row_Rendering();

		// Common render codes for all row types
		// lagnuage_id

		$tbl_country->lagnuage_id->CellCssStyle = ""; $tbl_country->lagnuage_id->CellCssClass = "";
		$tbl_country->lagnuage_id->CellAttrs = array(); $tbl_country->lagnuage_id->ViewAttrs = array(); $tbl_country->lagnuage_id->EditAttrs = array();

		// country_name
		$tbl_country->country_name->CellCssStyle = ""; $tbl_country->country_name->CellCssClass = "";
		$tbl_country->country_name->CellAttrs = array(); $tbl_country->country_name->ViewAttrs = array(); $tbl_country->country_name->EditAttrs = array();

		// order_by
		$tbl_country->order_by->CellCssStyle = ""; $tbl_country->order_by->CellCssClass = "";
		$tbl_country->order_by->CellAttrs = array(); $tbl_country->order_by->ViewAttrs = array(); $tbl_country->order_by->EditAttrs = array();
		if ($tbl_country->RowType == EW_ROWTYPE_VIEW) { // View row

			// country_id
			$tbl_country->country_id->ViewValue = $tbl_country->country_id->CurrentValue;
			$tbl_country->country_id->CssStyle = "";
			$tbl_country->country_id->CssClass = "";
			$tbl_country->country_id->ViewCustomAttributes = "";

			// country_or_id
			if (strval($tbl_country->country_or_id->CurrentValue) <> "") {
				$sFilterWrk = "`country_or_id` = " . ew_AdjustSql($tbl_country->country_or_id->CurrentValue) . "";
			$sSqlWrk = "SELECT `country` FROM `tbl_country_original`";
			$sWhereWrk = "";
			if ($sFilterWrk <> "") {
				if ($sWhereWrk <> "") $sWhereWrk .= " AND ";
				$sWhereWrk .= "(" . $sFilterWrk . ")";
			}
			if ($sWhereWrk <> "") $sSqlWrk .= " WHERE " . $sWhereWrk;
				$rswrk = $conn->Execute($sSqlWrk);
				if ($rswrk && !$rswrk->EOF) { // Lookup values found
					$tbl_country->country_or_id->ViewValue = $rswrk->fields('country');
					$rswrk->Close();
				} else {
					$tbl_country->country_or_id->ViewValue = $tbl_country->country_or_id->CurrentValue;
				}
			} else {
				$tbl_country->country_or_id->ViewValue = NULL;
			}
			$tbl_country->country_or_id->CssStyle = "";
			$tbl_country->country_or_id->CssClass = "";
			$tbl_country->country_or_id->ViewCustomAttributes = "";

			// lagnuage_id
			if (strval($tbl_country->lagnuage_id->CurrentValue) <> "") {
				$sFilterWrk = "`language_id` = " . ew_AdjustSql($tbl_country->lagnuage_id->CurrentValue) . "";
			$sSqlWrk = "SELECT `language` FROM `tbl_language`";
			$sWhereWrk = "";
			if ($sFilterWrk <> "") {
				if ($sWhereWrk <> "") $sWhereWrk .= " AND ";
				$sWhereWrk .= "(" . $sFilterWrk . ")";
			}
			if ($sWhereWrk <> "") $sSqlWrk .= " WHERE " . $sWhereWrk;
				$rswrk = $conn->Execute($sSqlWrk);
				if ($rswrk && !$rswrk->EOF) { // Lookup values found
					$tbl_country->lagnuage_id->ViewValue = $rswrk->fields('language');
					$rswrk->Close();
				} else {
					$tbl_country->lagnuage_id->ViewValue = $tbl_country->lagnuage_id->CurrentValue;
				}
			} else {
				$tbl_country->lagnuage_id->ViewValue = NULL;
			}
			$tbl_country->lagnuage_id->CssStyle = "";
			$tbl_country->lagnuage_id->CssClass = "";
			$tbl_country->lagnuage_id->ViewCustomAttributes = "";

			// country_name
			$tbl_country->country_name->ViewValue = $tbl_country->country_name->CurrentValue;
			$tbl_country->country_name->CssStyle = "";
			$tbl_country->country_name->CssClass = "";
			$tbl_country->country_name->ViewCustomAttributes = "";

			// order_by
			$tbl_country->order_by->ViewValue = $tbl_country->order_by->CurrentValue;
			$tbl_country->order_by->CssStyle = "";
			$tbl_country->order_by->CssClass = "";
			$tbl_country->order_by->ViewCustomAttributes = "";

			// lagnuage_id
			$tbl_country->lagnuage_id->HrefValue = "";
			$tbl_country->lagnuage_id->TooltipValue = "";

			// country_name
			$tbl_country->country_name->HrefValue = "";
			$tbl_country->country_name->TooltipValue = "";

			// order_by
			$tbl_country->order_by->HrefValue = "";
			$tbl_country->order_by->TooltipValue = "";
		}

		// Call Row Rendered event
		if ($tbl_country->RowType <> EW_ROWTYPE_AGGREGATEINIT)
			$tbl_country->Row_Rendered();
	}

	// Page Load event
	function Page_Load() {

		//echo "Page Load";
	}

	// Page Unload event
	function Page_Unload() {

		//echo "Page Unload";
	}

	// Page Redirecting event
	function Page_Redirecting(&$url) {

		// Example:
		//$url = "your URL";

	}

	// Message Showing event
	function Message_Showing(&$msg) {

		// Example:
		//$msg = "your new message";

	}
}
?>
